@@ -17,8 +17,32 @@ from mezzanine.conf import register_setting
 
 
 register_setting(
-    name="ACCOUNTS_ENABLED",
-    description="If True, users can create an account.",
+    name="ACCOUNTS_MIN_PASSWORD_LENGTH",
+    description=_("Minimum length for passwords"),
+    editable=False,
+    default=6,
+)
+
+register_setting(
+    name="ACCOUNTS_PROFILE_FORM_EXCLUDE_FIELDS",
+    description=_("List of fields to exclude from the profile form."),
+    editable=False,
+    default=(),
+)
+
+register_setting(
+    name="ACCOUNTS_PROFILE_VIEWS_ENABLED",
+    description=_("If ``True``, users will have their own public profile "
+        "pages."),
+    editable=False,
+    default=False,
+)
+
+register_setting(
+    name="ACCOUNTS_VERIFICATION_REQUIRED",
+    description=_("If ``True``, when users create an account, they will be "
+        "sent an email with a verification link, which they must click to "
+        "enable their account."),
     editable=False,
     default=False,
 )
@@ -45,7 +69,7 @@ register_setting(
 register_setting(
     name="BLOG_BITLY_USER",
     label=_("bit.ly username"),
-    description=_("Username for bit.ly URL shortening service."),
+    description=_("Username for http://bit.ly URL shortening service."),
     editable=True,
     default="",
 )
@@ -53,7 +77,7 @@ register_setting(
 register_setting(
     name="BLOG_BITLY_KEY",
     label=_("bit.ly key"),
-    description=_("Key for bit.ly URL shortening service."),
+    description=_("Key for http://bit.ly URL shortening service."),
     editable=True,
     default="",
 )
@@ -89,6 +113,38 @@ register_setting(
     default="blog",
 )
 
+register_setting(
+    name="CACHE_SET_DELAY_SECONDS",
+    description=_("Mezzanine's caching uses a technique know as mint "
+        "caching. This is where the requested expiry for a cache entry "
+        "is stored with the cache entry in cache, and the real expiry "
+        "used has the ``CACHE_SET_DELAY`` added to it. Then on a cache get, "
+        "the store expiry is checked, and if it has past, the cache entry "
+        "is set again, and no entry is returned. This tries to ensure that "
+        "cache misses never occur, and if many clients were to get a cache "
+        "miss at once, only one would actually need to re-generated the "
+        "cache entry."),
+    editable=False,
+    default=30,
+)
+
+register_setting(
+    name="COMMENTS_ACCOUNT_REQUIRED",
+    label=_("Accounts required for commenting"),
+    description=_("If ``True``, users must log in to comment."),
+    editable=True,
+    default=False,
+)
+
+register_setting(
+    name="AKISMET_API_KEY",
+    label=_("Akismet API Key"),
+    description=_("Key for http://akismet.com spam filtering service. Used "
+        "for filtering comments and forms."),
+    editable=True,
+    default="",
+)
+
 register_setting(
     name="COMMENTS_DISQUS_SHORTNAME",
     label=_("Disqus shortname"),
@@ -100,7 +156,7 @@ register_setting(
 register_setting(
     name="COMMENTS_DISQUS_API_PUBLIC_KEY",
     label=_("Disqus public key"),
-    description=_("Public key for Disqus developer API"),
+    description=_("Public key for http://disqus.com developer API"),
     editable=True,
     default="",
 )
@@ -108,7 +164,7 @@ register_setting(
 register_setting(
     name="COMMENTS_DISQUS_API_SECRET_KEY",
     label=_("Disqus secret key"),
-    description=_("Secret key for Disqus developer API"),
+    description=_("Secret key for http://disqus.com developer API"),
     editable=True,
     default="",
 )
@@ -239,8 +295,7 @@ register_setting(
 
 register_setting(
     name="FORMS_USE_HTML5",
-    description=_("If ``True``, website forms created by the forms app will "
-        "use HTML5 features."),
+    description=_("If ``True``, website forms will use HTML5 features."),
     editable=False,
     default=False,
 )
@@ -372,6 +427,39 @@ register_setting(
     default=None,
 )
 
+RICHTEXT_FILTER_LEVEL_HIGH = 1
+RICHTEXT_FILTER_LEVEL_LOW = 2
+RICHTEXT_FILTER_LEVEL_NONE = 3
+RICHTEXT_FILTER_LEVELS = (
+    (RICHTEXT_FILTER_LEVEL_HIGH, _("High")),
+    (RICHTEXT_FILTER_LEVEL_LOW, _("Low (allows video, iframe, Flash, etc)")),
+    (RICHTEXT_FILTER_LEVEL_NONE, _("No filtering")),
+)
+
+register_setting(
+    name="RICHTEXT_FILTER_LEVEL",
+    label=_("Rich Text filter level"),
+    description=_("*Do not change this setting unless you know what you're "
+        "doing.*\n\nWhen content is saved in a Rich Text (WYSIWYG) field, "
+        "unsafe HTML tags and attributes are stripped from the content to "
+        "protect against staff members intentionally adding code that could "
+        "be used to cause problems, such as changing their account to "
+        "a super-user with full access to the system.\n\n"
+        "This setting allows you to change the level of filtering that "
+        "occurs. Setting it to low will allow certain extra tags to be "
+        "permitted, such as those required for embedding video. While these "
+        "tags are not the main candidates for users adding malicious code, "
+        "they are still considered dangerous and could potentially be "
+        "mis-used by a particularly technical user, and so are filtered out "
+        "when the filtering level is set to high.\n\n"
+        "Setting the filtering level to no filtering, will disable all "
+        "filtering, and allow any code to be entered by staff members, "
+        "including script tags."),
+    editable=True,
+    choices=RICHTEXT_FILTER_LEVELS,
+    default=RICHTEXT_FILTER_LEVEL_HIGH,
+)
+
 register_setting(
     name="SEARCH_PER_PAGE",
     label=_("Search results per page"),
@@ -397,12 +485,23 @@ register_setting(
     default=_("An open source content management platform."),
 )
 
+register_setting(
+    name="SLUGIFY",
+    description=_("Dotted Python path to the callable for converting "
+        "strings into URL slugs. Defaults to "
+        "``mezzanine.utils.urls.slugify_unicode`` which allows for non-ascii "
+        "URLS. Change to ``django.template.defaultfilters.slugify`` to use "
+        "Django's slugify function, or something of your own if required."),
+    editable=False,
+    default="mezzanine.utils.urls.slugify_unicode",
+)
+
 register_setting(
     name="SSL_ENABLED",
     label=_("Enable SSL"),
-    description="If ``True``, users will be automatically redirected to HTTPS "
-                "for the URLs specified by the ``SSL_FORCE_URL_PREFIXES`` "
-                "setting.",
+    description=_("If ``True``, users will be automatically redirected to "
+        "HTTPS for the URLs specified by the ``SSL_FORCE_URL_PREFIXES`` "
+        "setting."),
     editable=True,
     default=False,
 )
@@ -410,8 +509,8 @@ register_setting(
 register_setting(
     name="SSL_FORCE_HOST",
     label=_("Force Host"),
-    description="Host name that the site should always be accessed via that "
-                "matches the SSL certificate.",
+    description=_("Host name that the site should always be accessed via that "
+                "matches the SSL certificate."),
     editable=True,
     default="",
 )
@@ -496,7 +595,7 @@ register_setting(
     description=_("Sequence of setting names available within templates."),
     editable=False,
     default=(
-        "ACCOUNTS_ENABLED", "ADMIN_MEDIA_PREFIX",
+        "ACCOUNTS_VERIFICATION_REQUIRED", "ADMIN_MEDIA_PREFIX",
         "BLOG_BITLY_USER", "BLOG_BITLY_KEY",
         "COMMENTS_DISQUS_SHORTNAME", "COMMENTS_NUM_LATEST",
         "COMMENTS_DISQUS_API_PUBLIC_KEY", "COMMENTS_DISQUS_API_SECRET_KEY",
