@@ -1,13 +1,24 @@
 
 from bleach import clean
+from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from mezzanine.conf import settings
 
 from mezzanine.utils.importing import import_dotted_path
 
 
+# Tags and attributes added to richtext filtering whitelist when the
+# RICHTEXT_FILTER_LEVEL is set to low. General use-case for these is
+# allowing embedded video, but we will add to this fixed list over
+# time as more use-cases come up. We won't ever add script tags or
+# events (onclick etc) to this list. To enable those, filtering can
+# be turned off in the settings admin.
+LOW_FILTER_TAGS = ("iframe", "embed", "video", "param", "source", "object")
+LOW_FILTER_ATTRS = ("allowfullscreen", "autostart", "loop", "hidden",
+                    "playcount", "volume", "controls", "data", "classid")
+
+
 class RichTextField(models.TextField):
     """
     TextField that stores HTML.
@@ -33,8 +44,18 @@ class RichTextField(models.TextField):
         """
         Remove potentially dangerous HTML tags and attributes.
         """
-        return clean(value, settings.RICHTEXT_ALLOWED_TAGS,
-                            settings.RICHTEXT_ALLOWED_ATTRIBUTES)
+        from mezzanine.conf import settings
+        from mezzanine.conf.defaults import (RICHTEXT_FILTER_LEVEL_NONE,
+                                             RICHTEXT_FILTER_LEVEL_LOW)
+        settings.use_editable()
+        if settings.RICHTEXT_FILTER_LEVEL == RICHTEXT_FILTER_LEVEL_NONE:
+            return value
+        tags = settings.RICHTEXT_ALLOWED_TAGS
+        attrs = settings.RICHTEXT_ALLOWED_ATTRIBUTES
+        if settings.RICHTEXT_FILTER_LEVEL == RICHTEXT_FILTER_LEVEL_LOW:
+            tags += LOW_FILTER_TAGS
+            attrs += LOW_FILTER_ATTRS
+        return clean(value, tags=tags, attributes=attrs, strip=True)
 
 
 # Define a ``FileField`` that maps to filebrowser's ``FileBrowseField``
@@ -47,7 +68,7 @@ except ImportError:
 else:
     class FileField(FileBrowseField):
         def __init__(self, *args, **kwargs):
-            kwargs.pop("upload_to", "")
+            kwargs.setdefault("directory", kwargs.pop("upload_to", None))
             super(FileField, self).__init__(*args, **kwargs)
 
 
