@@ -1,34 +1,57 @@
-from datetime import datetime
 
 from django.contrib.contenttypes.generic import GenericForeignKey
-from django.contrib.sites.models import Site
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.db.models.base import ModelBase
 from django.template.defaultfilters import truncatewords_html
 from django.utils.html import strip_tags
+from django.utils.timesince import timesince
 from django.utils.translation import ugettext, ugettext_lazy as _
-from django.contrib.sites.managers import CurrentSiteManager
 
 from mezzanine.core.fields import RichTextField
-from mezzanine.core.managers import DisplayableManager
+from mezzanine.core.managers import DisplayableManager, CurrentSiteManager
 from mezzanine.generic.fields import KeywordsField
 from mezzanine.utils.html import TagCloser
 from mezzanine.utils.models import base_concrete_model
+from mezzanine.utils.sites import current_site_id
+from mezzanine.utils.timezone import now
 from mezzanine.utils.urls import slugify
 
 
-class Slugged(models.Model):
+class SiteRelated(models.Model):
+    """
+    Abstract model for all things site-related. Adds a foreignkey to
+    Django's ``Site`` model, and filters by site with all querysets.
+    See ``mezzanine.utils.sites.current_site_id`` for implementation
+    details.
+    """
+
+    objects = CurrentSiteManager()
+
+    class Meta:
+        abstract = True
+
+    site = models.ForeignKey("sites.Site", editable=False)
+
+    def save(self, update_site=False, *args, **kwargs):
+        """
+        Set the site to the current site when the record is first
+        created, or the ``update_site`` argument is explicitly set
+        to ``True``.
+        """
+        if update_site or not self.id:
+            self.site_id = current_site_id()
+        super(SiteRelated, self).save(*args, **kwargs)
+
+
+class Slugged(SiteRelated):
     """
     Abstract model that handles auto-generating slugs. Each slugged
     object is also affiliated with a specific site object.
     """
 
-    title = models.CharField(_("Title"), max_length=100)
-    slug = models.CharField(_("URL"), max_length=100, blank=True, null=True)
-    site = models.ForeignKey(Site, editable=False)
-
-    objects = CurrentSiteManager()
+    title = models.CharField(_("Title"), max_length=500)
+    slug = models.CharField(_("URL"), max_length=2000, blank=True, null=True)
 
     class Meta:
         abstract = True
@@ -37,11 +60,9 @@ class Slugged(models.Model):
     def __unicode__(self):
         return self.title
 
-    def save(self, update_site=False, *args, **kwargs):
+    def save(self, *args, **kwargs):
         """
-        Create a unique slug by appending an index. Set the site to
-        the current site when the record is first created, unless the
-        ``update_site`` argument is explicitly set to ``True``.
+        Create a unique slug by appending an index.
         """
         if not self.slug:
             # For custom content types, use the ``Page`` instance for
@@ -62,8 +83,6 @@ class Slugged(models.Model):
                 except ObjectDoesNotExist:
                     break
                 i += 1
-        if update_site or not self.id:
-            self.site = Site.objects.get_current()
         super(Slugged, self).save(*args, **kwargs)
 
     def get_slug(self):
@@ -85,6 +104,10 @@ class MetaData(models.Model):
     """
 
     description = models.TextField(_("Description"), blank=True)
+    gen_description = models.BooleanField(_("Generate description"),
+        help_text=_("If checked, the description will be automatically "
+                    "generated from content. Uncheck if you want to manually "
+                    "set a custom description."), default=True)
     keywords = KeywordsField(verbose_name=_("Keywords"))
 
     class Meta:
@@ -94,7 +117,8 @@ class MetaData(models.Model):
         """
         Set the description field on save.
         """
-        self.description = strip_tags(self.description_from_content())
+        if self.gen_description:
+            self.description = strip_tags(self.description_from_content())
         super(MetaData, self).save(*args, **kwargs)
 
     def description_from_content(self):
@@ -166,9 +190,16 @@ class Displayable(Slugged, MetaData):
         the quick blog form in the admin dashboard.
         """
         if self.publish_date is None:
-            self.publish_date = datetime.now()
+            self.publish_date = now()
         super(Displayable, self).save(*args, **kwargs)
 
+    def publish_date_since(self):
+        """
+        Returns the time since ``publish_date``.
+        """
+        return timesince(self.publish_date)
+    publish_date_since.short_description = _("Published from")
+
 
 class RichText(models.Model):
     """
