@@ -1,40 +1,103 @@
 
 from __future__ import with_statement
+from hashlib import md5
 import os
-from urllib import urlopen, urlencode
+from urllib import urlopen, urlencode, quote, unquote
 
 from django.contrib import admin
 from django.contrib.auth import REDIRECT_FIELD_NAME
+from django.contrib.sites.models import Site
 from django.core.files import File
 from django.core.files.storage import default_storage
 from django.core.urlresolvers import reverse, NoReverseMatch
 from django.db.models import Model
-from django.template import Context, Template
+from django.template import (Context, Node, TextNode, Template,
+                             TemplateSyntaxError, TOKEN_TEXT, TOKEN_VAR,
+                             TOKEN_COMMENT, TOKEN_BLOCK)
+
 from django.template.loader import get_template
 from django.utils.html import strip_tags
 from django.utils.simplejson import loads
 from django.utils.text import capfirst
+
 from PIL import Image, ImageOps
 
 from mezzanine.conf import settings
 from mezzanine.core.fields import RichTextField
 from mezzanine.core.forms import get_edit_form
+from mezzanine.utils.cache import nevercache_token, cache_installed
 from mezzanine.utils.html import decode_entities
 from mezzanine.utils.importing import import_dotted_path
-from mezzanine.utils.views import is_editable
+from mezzanine.utils.sites import current_site_id
 from mezzanine.utils.urls import admin_url
+from mezzanine.utils.views import is_editable
 from mezzanine import template
 
 
 register = template.Library()
 
 
+if "compressor" in settings.INSTALLED_APPS:
+    @register.tag
+    def compress(parser, token):
+        """
+        Shadows django-compressor's compress tag so it can be
+        loaded from ``mezzanine_tags``, allowing us to provide
+        a dummy version when django-compressor isn't installed.
+        """
+        from compressor.templatetags.compress import compress
+        return compress(parser, token)
+else:
+    @register.to_end_tag
+    def compress(parsed, context, token):
+        """
+        Dummy tag for fallback when django-compressor isn't installed.
+        """
+        return parsed
+
+
+if cache_installed():
+    @register.tag
+    def nevercache(parser, token):
+        """
+        Tag for two phased rendering. Converts enclosed template
+        code and content into text, which gets rendered separately
+        in ``mezzanine.core.middleware.UpdateCacheMiddleware``.
+        This is to bypass caching for the enclosed code and content.
+        """
+        text = []
+        end_tag = "endnevercache"
+        tag_mapping = {
+            TOKEN_TEXT: ("", ""),
+            TOKEN_VAR: ("{{", "}}"),
+            TOKEN_BLOCK: ("{%", "%}"),
+            TOKEN_COMMENT: ("{#", "#}"),
+        }
+        delimiter = nevercache_token()
+        while parser.tokens:
+            token = parser.next_token()
+            if token.token_type == TOKEN_BLOCK and token.contents == end_tag:
+                return TextNode(delimiter + "".join(text) + delimiter)
+            start, end = tag_mapping[token.token_type]
+            text.append("%s%s%s" % (start, token.contents, end))
+        parser.unclosed_block_tag(end_tag)
+else:
+    @register.to_end_tag
+    def nevercache(parsed, context, token):
+        """
+        Dummy fallback ``nevercache`` for when caching is not
+        configured.
+        """
+        return parsed
+
+
 @register.inclusion_tag("includes/form_fields.html", takes_context=True)
 def fields_for(context, form):
     """
     Renders fields for a form.
     """
-    return {"form": form}
+    context["form_for_fields"] = form
+    return context
 
 
 @register.filter
@@ -43,9 +106,50 @@ def is_installed(app_name):
     Returns ``True`` if the given app name is in the
     ``INSTALLED_APPS`` setting.
     """
+    from warnings import warn
+    warn("The is_installed filter is deprecated. Please use the tag "
+         "{% ifinstalled appname %}{% endifinstalled %}")
     return app_name in settings.INSTALLED_APPS
 
 
+@register.tag
+def ifinstalled(parser, token):
+    """
+    Old-style ``if`` tag that renders contents if the given app is
+    installed. The main use case is:
+
+    {% ifinstalled app_name %}
+    {% include "app_name/template.html" %}
+    {% endifinstalled %}
+
+    so we need to manually pull out all tokens if the app isn't
+    installed, since if we used a normal ``if`` tag with a False arg,
+    the include tag will still try and find the template to include.
+    """
+    try:
+        tag, app = token.split_contents()
+    except ValueError:
+        raise TemplateSyntaxError("ifinstalled should be in the form: "
+                                  "{% ifinstalled app_name %}"
+                                  "{% endifinstalled %}")
+
+    end_tag = "end" + tag
+    if app.strip("\"'") not in settings.INSTALLED_APPS:
+        while True:
+            token = parser.tokens.pop(0)
+            if token.token_type == TOKEN_BLOCK and token.contents == end_tag:
+                parser.tokens.insert(0, token)
+                break
+    nodelist = parser.parse((end_tag,))
+    parser.delete_first_token()
+
+    class IfInstalledNode(Node):
+        def render(self, context):
+            return nodelist.render(context)
+
+    return IfInstalledNode()
+
+
 @register.render_tag
 def set_short_url_for(context, token):
     """
@@ -70,6 +174,15 @@ def set_short_url_for(context, token):
     return ""
 
 
+@register.simple_tag
+def gravatar_url(email, size=32):
+    """
+    Return the full URL for a Gravatar given an email hash.
+    """
+    email_hash = md5(email).hexdigest()
+    return "http://www.gravatar.com/avatar/%s?s=%s" % (email_hash, size)
+
+
 @register.to_end_tag
 def metablock(parsed):
     """
@@ -93,7 +206,7 @@ def pagination_for(context, current_page):
 
 
 @register.simple_tag
-def thumbnail(image_url, width, height):
+def thumbnail(image_url, width, height, quality=95):
     """
     Given the URL to an image, resizes the image using the given width and
     height on the first time it is requested, and returns the URL to the new
@@ -103,7 +216,7 @@ def thumbnail(image_url, width, height):
     if not image_url:
         return ""
 
-    image_url = unicode(image_url)
+    image_url = unquote(unicode(image_url))
     if image_url.startswith(settings.MEDIA_URL):
         image_url = image_url.replace(settings.MEDIA_URL, "", 1)
     image_dir, image_name = os.path.split(image_url)
@@ -115,16 +228,28 @@ def thumbnail(image_url, width, height):
     if not os.path.exists(thumb_dir):
         os.makedirs(thumb_dir)
     thumb_path = os.path.join(thumb_dir, thumb_name)
-    thumb_url = "%s/%s/%s" % (os.path.dirname(image_url),
-                              settings.THUMBNAILS_DIR_NAME, thumb_name)
+    thumb_url = "%s/%s" % (settings.THUMBNAILS_DIR_NAME, quote(thumb_name))
+    image_url_path = os.path.dirname(image_url)
+    if image_url_path:
+        thumb_url = "%s/%s" % (image_url_path, thumb_url)
 
-    # Abort if thumbnail exists or original image doesn't exist.
-    if os.path.exists(thumb_path):
+    try:
+        thumb_exists = os.path.exists(thumb_path)
+    except UnicodeEncodeError:
+        # The image that was saved to a filesystem with utf-8 support,
+        # but somehow the locale has changed and the filesystem does not
+        # support utf-8.
+        from mezzanine.core.exceptions import FileSystemEncodingChanged
+        raise FileSystemEncodingChanged()
+    if thumb_exists:
+        # Thumbnail exists, don't generate it.
         return thumb_url
     elif not default_storage.exists(image_url):
+        # Requested image does not exist, just return its URL.
         return image_url
 
     image = Image.open(default_storage.open(image_url))
+    image_info = image.info
     width = int(width)
     height = int(height)
 
@@ -136,11 +261,11 @@ def thumbnail(image_url, width, height):
         width = image.size[0] * height / image.size[1]
     elif height == 0:
         height = image.size[1] * width / image.size[0]
-    if image.mode not in ("L", "RGB"):
-        image = image.convert("RGB")
+    if image.mode not in ("L", "RGBA"):
+        image = image.convert("RGBA")
     try:
         image = ImageOps.fit(image, (width, height), Image.ANTIALIAS)
-        image = image.save(thumb_path, filetype, quality=100)
+        image = image.save(thumb_path, filetype, quality=quality, **image_info)
         # Push a remote copy of the thumbnail if MEDIA_URL is
         # absolute.
         if "://" in settings.MEDIA_URL:
@@ -218,6 +343,8 @@ def try_url(url_name):
     names in admin templates as these won't resolve when admin tests are
     running.
     """
+    from warnings import warn
+    warn("try_url is deprecated, use the url tag with the 'as' arg instead.")
     try:
         url = reverse(url_name)
     except NoReverseMatch:
@@ -285,20 +412,23 @@ def admin_app_list(request):
         name = unicode(name)
         for unfound_item in set(items) - found_items:
             if isinstance(unfound_item, (list, tuple)):
-                item_name, item_url = unfound_item[0], try_url(unfound_item[1])
-                if item_url:
-                    if name not in app_dict:
-                        app_dict[name] = {
-                            "index": i,
-                            "name": name,
-                            "models": [],
-                        }
-                    app_dict[name]["models"].append({
-                        "index": items.index(unfound_item),
-                        "perms": {"custom": True},
-                        "name": item_name,
-                        "admin_url": item_url,
-                    })
+                item_name, item_url = unfound_item[0], unfound_item[1]
+                try:
+                    item_url = reverse(item_url)
+                except NoReverseMatch:
+                    continue
+                if name not in app_dict:
+                    app_dict[name] = {
+                        "index": i,
+                        "name": name,
+                        "models": [],
+                    }
+                app_dict[name]["models"].append({
+                    "index": items.index(unfound_item),
+                    "perms": {"custom": True},
+                    "name": item_name,
+                    "admin_url": item_url,
+                })
 
     app_list = app_dict.values()
     sort = lambda x: x["name"] if x["index"] is None else x["index"]
@@ -315,6 +445,8 @@ def admin_dropdown_menu(context):
     Renders the app list for the admin dropdown menu navigation.
     """
     context["dropdown_menu_app_list"] = admin_app_list(context["request"])
+    context["dropdown_menu_sites"] = list(Site.objects.all())
+    context["dropdown_menu_selected_site_id"] = current_site_id()
     return context
 
 
