@@ -1,7 +1,8 @@
-from datetime import date, datetime
+from datetime import date
 from os.path import join, split
 from uuid import uuid4
 
+import django
 from django import forms
 from django.forms.extras import SelectDateWidget
 from django.core.files.storage import FileSystemStorage
@@ -12,6 +13,7 @@ from django.utils.translation import ugettext_lazy as _
 from mezzanine.conf import settings
 from mezzanine.forms import fields
 from mezzanine.forms.models import FormEntry, FieldEntry
+from mezzanine.utils.timezone import now
 
 
 fs = FileSystemStorage(location=settings.FORMS_UPLOAD_ROOT)
@@ -79,7 +81,7 @@ class FormForForm(forms.ModelForm):
         """
         self.form = form
         self.form_fields = form.fields.visible()
-        field_entries = {}
+        initial = kwargs.pop("initial", {})
         # If a FormEntry instance is given to edit, populate initial
         # with its field values.
         field_entries = {}
@@ -94,6 +96,8 @@ class FormForForm(forms.ModelForm):
             field_widget = fields.WIDGETS.get(field.field_type)
             field_args = {"label": field.label, "required": field.required,
                           "help_text": field.help_text}
+            if field.required and not field.help_text:
+                field_args["help_text"] = _("required")
             arg_names = field_class.__init__.im_func.func_code.co_varnames
             if "max_length" in arg_names:
                 field_args["max_length"] = settings.FORMS_FIELD_MAX_LENGTH
@@ -101,10 +105,28 @@ class FormForForm(forms.ModelForm):
                 field_args["choices"] = field.get_choices()
             if field_widget is not None:
                 field_args["widget"] = field_widget
+            #
+            #   Initial value for field, in order of preference:
+            #
+            # - If a form model instance is given (eg we're editing a
+            #   form response), then use the instance's value for the
+            #   field.
+            # - If the developer has provided an explicit "initial"
+            #   dict, use it.
+            # - The default value for the field instance as given in
+            #   the admin.
+            #
             try:
-                self.initial[field_key] = field_entries[field.id]
+                initial_val = field_entries[field.id]
             except KeyError:
-                self.initial[field_key] = field.default
+                try:
+                    self.initial[field_key] = initial[field_key]
+                except KeyError:
+                    self.initial[field_key] = field.default
+            else:
+                if field.is_a(*fields.MULTIPLE):
+                    initial_val = [x.strip() for x in initial_val.split(",")]
+                self.initial[field_key] = initial_val
             self.fields[field_key] = field_class(**field_args)
             # Add identifying type attr to the field for styling.
             setattr(self.fields[field_key], "type",
@@ -123,8 +145,10 @@ class FormForForm(forms.ModelForm):
         """
         entry = super(FormForForm, self).save(commit=False)
         entry.form = self.form
-        entry.entry_time = datetime.now()
+        entry.entry_time = now()
         entry.save()
+        entry_fields = entry.fields.values_list("field_id", flat=True)
+        new_entry_fields = []
         for field in self.form_fields:
             field_key = "field_%s" % field.id
             value = self.cleaned_data[field_key]
@@ -132,9 +156,19 @@ class FormForForm(forms.ModelForm):
                 value = fs.save(join("forms", str(uuid4()), value.name), value)
             if isinstance(value, list):
                 value = ", ".join([v.strip() for v in value])
-            field_entry, _ = entry.fields.get_or_create(field_id=field.id)
-            field_entry.value = value
-            field_entry.save()
+            if field.id in entry_fields:
+                field_entry = entry.fields.get(field_id=field.id)
+                field_entry.value = value
+                field_entry.save()
+            else:
+                new = {"entry": entry, "field_id": field.id, "value": value}
+                new_entry_fields.append(FieldEntry(**new))
+        if new_entry_fields:
+            if django.VERSION >= (1, 4, 0):
+                FieldEntry.objects.bulk_create(new_entry_fields)
+            else:
+                for field_entry in new_entry_fields:
+                    field_entry.save()
         return entry
 
     def email_to(self):
@@ -281,7 +315,7 @@ class EntriesForm(forms.Form):
                 valid_row = True
                 if include_entry_time:
                     current_row[-1] = field_entry.entry.entry_time
-            field_value = field_entry.value
+            field_value = field_entry.value or ""
             # Check for filter.
             field_id = field_entry.field_id
             filter_type = self.cleaned_data.get("field_%s_filter" % field_id)
@@ -317,7 +351,7 @@ class EntriesForm(forms.Form):
                     if not filter_func(*filter_args):
                         valid_row = False
             # Create download URL for file fields.
-            if field_id in file_field_ids:
+            if field_entry.value and field_id in file_field_ids:
                 url = reverse("admin:form_file", args=(field_entry.id,))
                 field_value = self.request.build_absolute_uri(url)
                 if not csv:
