@@ -6,9 +6,14 @@ from mezzanine.forms.forms import FormForForm
 from mezzanine.forms.models import Form
 from mezzanine.pages.page_processors import processor_for
 from mezzanine.utils.email import send_mail_template
+from mezzanine.utils.views import is_spam
 
 
 def format_value(value):
+    """
+    Convert a list into a comma separated string, for displaying
+    select multiple values in emails.
+    """
     if isinstance(value, list):
         value = ", ".join([v.strip() for v in value])
     return value
@@ -21,6 +26,9 @@ def form_processor(request, page):
     """
     form = FormForForm(page.form, request.POST or None, request.FILES or None)
     if form.is_valid():
+        url = page.get_absolute_url() + "?sent=1"
+        if is_spam(request, form, url):
+            return redirect(url)
         entry = form.save()
         subject = page.form.email_subject
         if not subject:
@@ -51,5 +59,5 @@ def form_processor(request, page):
             send_mail_template(subject, "email/form_response", email_from,
                                email_copies, context, attachments=attachments,
                                fail_silently=settings.DEBUG)
-        return redirect(page.get_absolute_url() + "?sent=1")
+        return redirect(url)
     return {"form": form}
