@@ -1,12 +1,18 @@
 
 from django.contrib.admin.views.decorators import staff_member_required
+from django.contrib.messages import error
+from django.contrib.comments.signals import comment_was_posted
+from django.core.urlresolvers import reverse
 from django.db.models import get_model, ObjectDoesNotExist
 from django.http import HttpResponse, HttpResponseRedirect
+from django.shortcuts import redirect
+from django.utils.translation import ugettext_lazy as _
 
+from mezzanine.conf import settings
 from mezzanine.generic.fields import RatingField
 from mezzanine.generic.forms import ThreadedCommentForm
 from mezzanine.generic.models import Keyword, Rating
-from mezzanine.utils.views import render, set_cookie
+from mezzanine.utils.views import render, set_cookie, is_spam
 
 
 @staff_member_required
@@ -34,30 +40,51 @@ def comment(request, template="generic/comments.html"):
     Handle a ``ThreadedCommentForm`` submission and redirect back to its
     related object.
     """
+
+    post_data = request.POST
+    settings.use_editable()
+    if settings.COMMENTS_ACCOUNT_REQUIRED:
+        if not request.user.is_authenticated():
+            # Account required but user isn't authenticated - store
+            # their post data in the session and redirect to login.
+            request.session["unauthenticated_comment"] = post_data
+            error(request, _("You must log in to comment. Please log in or "
+                             "sign up, and your comment will be posted."))
+            url = "%s?next=%s" % (settings.LOGIN_URL, reverse("comment"))
+            return redirect(url)
+        elif "unauthenticated_comment" in request.session:
+            # User has logged in after post data being stored in the
+            # session for an unauthenticated comment post, so use it.
+            post_data = request.session.pop("unauthenticated_comment")
+
     try:
-        model = get_model(*request.POST["content_type"].split(".", 1))
-        obj = model.objects.get(id=request.POST["object_pk"])
-        if request.method != "POST":
-            raise ObjectDoesNotExist()
+        model = get_model(*post_data["content_type"].split(".", 1))
+        obj = model.objects.get(id=post_data["object_pk"])
     except (KeyError, TypeError, AttributeError, ObjectDoesNotExist):
         # Something was missing from the post so abort.
         return HttpResponseRedirect("/")
-    form = ThreadedCommentForm(request, obj, request.POST or None)
+
+    form = ThreadedCommentForm(request, obj, post_data)
     if form.is_valid():
+        url = obj.get_absolute_url()
+        if is_spam(request, form, url):
+            return redirect(url)
         comment = form.get_comment_object()
         if request.user.is_authenticated():
             comment.user = request.user
         comment.by_author = request.user == getattr(obj, "user", None)
         comment.ip_address = request.META.get("HTTP_X_FORWARDED_FOR",
                                               request.META["REMOTE_ADDR"])
-        comment.replied_to_id = request.POST.get("replied_to")
+        comment.replied_to_id = post_data.get("replied_to")
         comment.save()
+        comment_was_posted.send(sender=comment.__class__, comment=comment,
+                                request=request)
         response = HttpResponseRedirect(comment.get_absolute_url())
         # Store commenter's details in a cookie for 90 days.
         cookie_expires = 60 * 60 * 24 * 90
         for field in ThreadedCommentForm.cookie_fields:
             cookie_name = ThreadedCommentForm.cookie_prefix + field
-            cookie_value = request.POST.get(field, "")
+            cookie_value = post_data.get(field, "")
             set_cookie(response, cookie_name, cookie_value, cookie_expires)
         return response
     else:
