@@ -42,7 +42,6 @@ def page_menu(context, token):
             raise TemplateSyntaxError(error)
     context["menu_template_name"] = template_name
     if "menu_pages" not in context:
-        pages = defaultdict(list)
         try:
             user = context["request"].user
             slug = context["request"].path
@@ -52,8 +51,23 @@ def page_menu(context, token):
         num_children = lambda id: lambda: len(context["menu_pages"][id])
         has_children = lambda id: lambda: num_children(id)() > 0
         published = Page.objects.published(for_user=user)
+        # Store the current page being viewed in the context. Used
+        # for comparisons in page.set_menu_helpers.
+        if "page" not in context:
+            try:
+                context["_current_page"] = published.get(slug=slug)
+            except Page.DoesNotExist:
+                context["_current_page"] = None
+        elif slug:
+            context["_current_page"] = context["page"]
+        # Maintain a dict of page IDs -> parent IDs for fast
+        # lookup in setting page.is_current_or_ascendant in
+        # page.set_menu_helpers.
+        context["_parent_page_ids"] = {}
+        pages = defaultdict(list)
         for page in published.select_related(depth=2).order_by("_order"):
-            page.set_menu_helpers(slug)
+            context["_parent_page_ids"][page.id] = page.parent_id
+            page.set_menu_helpers(context)
             setattr(page, "num_children", num_children(page.id))
             setattr(page, "has_children", has_children(page.id))
             pages[page.parent_id].append(page)
@@ -65,10 +79,11 @@ def page_menu(context, token):
     # addition performed on it, the addition occurs each time the template
     # tag is called rather than once per level.
     context["branch_level"] = 0
+    parent_page_id = None
     if parent_page is not None:
         context["branch_level"] = getattr(parent_page, "branch_level", 0) + 1
-        parent_page = parent_page.id
-    context["page_branch"] = context["menu_pages"].get(parent_page, [])
+        parent_page_id = parent_page.id
+    context["page_branch"] = context["menu_pages"].get(parent_page_id, [])
     context['page_branch_in_navigation'] = False
     context['page_branch_in_footer'] = False
     for page in context["page_branch"]:
@@ -81,6 +96,7 @@ def page_menu(context, token):
             break
     for i, page in enumerate(context["page_branch"]):
         context["page_branch"][i].branch_level = context["branch_level"]
+        context["page_branch"][i].parent = parent_page
     t = get_template(template_name)
     return t.render(context)
 
@@ -135,10 +151,9 @@ def set_page_permissions(context, token):
     Used within the change list for pages, to implement permission
     checks for the navigation tree.
     """
-    page = context[token.split_contents()[1]]
-    model = page.get_content_model()
+    page = context[token.split_contents()[1]].get_content_model()
     try:
-        opts = model._meta
+        opts = page._meta
     except AttributeError:
         # A missing inner Meta class usually means the Page model
         # hasn't been directly subclassed.
@@ -152,4 +167,5 @@ def set_page_permissions(context, token):
         perm = request.user.has_perm(perm_name % perm_type)
         perm = perm and getattr(page, "can_%s" % perm_type)(request)
         page.perms[perm_type] = perm
+    context[token.split_contents()[1]] = page
     return ""
