@@ -41,13 +41,19 @@ def build_settings_docs(docs_path, prefix=None):
         if setting_default != dynamic:
             setting_default = repr(setting_default)
         lines.extend(["", settings_name, "-" * len(settings_name)])
-        lines.extend(["", setting["description"]])
+        lines.extend(["", setting["description"].replace("<b>", "``"
+            ).replace("</b>", "``").replace("<a href=\"", "`"
+            ).replace("\" rel=\"nofollow\">", " <").replace("</a>", ">`_")])
+        if setting["choices"]:
+            choices = ", ".join(["%s: ``%s``" % (v, k) for k, v in
+                                 setting["choices"]])
+            lines.extend(["", "Choices: %s" % choices, ""])
         lines.extend(["", "Default: ``%s``" % setting_default])
     with open(os.path.join(docs_path, "settings.rst"), "w") as f:
         f.write("\n".join(lines))
 
 # Python complains if this is inside build_changelog which uses exec.
-_changeset_date = lambda c: datetime.fromtimestamp(c.date()[0])
+_changeset_date = lambda cs: datetime.fromtimestamp(cs.date()[0])
 
 
 def build_changelog(docs_path, package_name="mezzanine"):
@@ -62,6 +68,13 @@ def build_changelog(docs_path, package_name="mezzanine"):
     changelog_file = os.path.join(project_path, changelog_filename)
     versions = SortedDict()
     repo = None
+    ignore = ("AUTHORS", "formatting", "typo", "pep8", "whitespace",
+              "README", "trans", "print debug", "debugging", "tabs",
+              "style", "sites", "ignore", "tweak", "cleanup", "minor")
+    hotfixes = {
+        "40cbc47b8d8a": "1.0.9",
+        "a25749986abc": "1.0.10",
+    }
 
     # Load the repo.
     try:
@@ -78,40 +91,53 @@ def build_changelog(docs_path, package_name="mezzanine"):
 
     # Go through each changeset and assign it to the versions dict.
     changesets = [repo.changectx(changeset) for changeset in repo.changelog]
-    for changeset in sorted(changesets, reverse=True, key=_changeset_date):
+    for cs in sorted(changesets, reverse=True, key=_changeset_date):
         # Check if the file with the version number is in this changeset
         # and if it is, pull it out and assign it as a variable.
-        files = changeset.files()
+        files = cs.files()
         new_version = False
+        description = cs.description().rstrip(".").replace("\n", "")
         if version_file in files:
-            for line in changeset[version_file].data().split("\n"):
+            for line in cs[version_file].data().split("\n"):
                 if line.startswith(version_var):
                     exec line
                     if locals()[version_var] == "0.1.0":
                         locals()[version_var] = "1.0.0"
                         break
-                    date = _changeset_date(changeset)
                     versions[locals()[version_var]] = {
-                        "changes": [], "date": date.strftime("%b %d, %Y")}
+                        "changes": [],
+                        "date": _changeset_date(cs).strftime("%b %d, %Y")
+                    }
                     new_version = len(files) == 1
         # Ignore changesets that are merges, bumped the version, closed
-        # a branch or regenerated the changelog itself.
-        merge = len(changeset.parents()) > 1
+        # a branch, regenerated the changelog itself, contain an ignore
+        # word, or are one word long.
+        merge = len(cs.parents()) > 1
         branch_closed = len(files) == 0
         changelog_update = changelog_filename in files
-        if merge or new_version or branch_closed or changelog_update:
+        ignored = [w for w in ignore if w.lower() in description.lower()]
+        one_word = len(description.split()) == 1
+        if (merge or new_version or branch_closed or changelog_update or
+            ignored or one_word):
             continue
         # Ensure we have a current version and if so, add this changeset's
         # description to it.
+        hotfix = hotfixes.get(cs.hex()[:12])
+        version = None
         try:
             version = locals()[version_var]
         except KeyError:
-            continue
-        else:
-            description = changeset.description().rstrip(".").replace("\n", "")
-            user = changeset.user().split("<")[0].strip()
-            entry = "%s - %s" % (description, user)
-            if entry not in versions[version]["changes"]:
+            if not hotfix:
+                continue
+        user = cs.user().split("<")[0].strip()
+        entry = "%s - %s" % (description, user)
+        if hotfix or entry not in versions[version]["changes"]:
+            if hotfix:
+                versions[hotfix] = {
+                    "changes": [entry],
+                    "date": _changeset_date(cs).strftime("%b %d, %Y"),
+                }
+            else:
                 versions[version]["changes"].insert(0, entry)
 
     # Write out the changelog.
